Crate toolpath_dot

Crate toolpath_dot 

Structs

RenderOptions
Options controlling what information is rendered in the DOT output.

Functions

actor_color
Return a fill color for a given actor string.
escape_dot
Escape a string for use in DOT label attributes (double-quoted context).
escape_html
Escape a string for use inside HTML-like DOT labels.
render
Render any Toolpath Document variant to a Graphviz DOT string.
render_graph
Render a Graph as a DOT digraph.
render_path
Render a Path as a DOT digraph.
render_step
Render a single Step as a DOT digraph.